@@ -20,6 +20,7 @@
 #ifndef __MT_MAIN_H__
 #define __MT_MAIN_H__
 
+#include <gdk/gdkx.h>
 #include <gconf/gconf-client.h>
 
 #include "mt-timer.h"
@@ -36,9 +37,13 @@ struct _MTClosure {
     MtTimer     *dwell_timer;
     MtCursor    *cursor;
 
+    Display *xtst_display;
+    gint     n_screens;
+
     gboolean dwell_drag_started;
     gboolean dwell_gesture_started;
     gboolean override_cursor;
+    gboolean move_release;
 
     gint direction;
     gint pointer_x;
